@@ -20,21 +20,13 @@
 # @author "HB"
 #*/###########################################################################
 setConstructorS3("XYCurveNormalization", function(...) {
-  extend(AbstractCurveNormalization(...), "XYCurveNormalization");
+  extend(AbstractCurveNormalization(...), "XYCurveNormalization")
 })
 
 setMethodS3("fitOne", "XYCurveNormalization", function(this, theta, ...) {
-  .fitXYCurve(theta, ...);
+  .fitXYCurve(theta, ...)
 }, protected=TRUE)
 
 setMethodS3("backtransformOne", "XYCurveNormalization", function(this, theta, fit, ...) {
-  .backtransformXYCurve(theta, fit=fit, ...);
+  .backtransformXYCurve(theta, fit=fit, ...)
 }, protected=TRUE)
-
-
-
-############################################################################
-# HISTORY:
-# 2009-07-15
-# o Created.
-############################################################################
