@@ -37,62 +37,62 @@ cnr <- function(start, stop=NULL, mean=1, chromosome=1, xScale=1e6, ...) {
   # Validate arguments
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
   # Argument 'start':
-  start <- Arguments$getNumerics(start, length=c(1,2));
+  start <- Arguments$getNumerics(start, length=c(1,2))
 
   # Argument 'start':
   if (is.null(stop)) {
     if (length(start) != 2) {
-      throw("If argument 'stop' is not specified/NULL, then argument 'start' must be of length two: ", length(start));
+      throw("If argument 'stop' is not specified/NULL, then argument 'start' must be of length two: ", length(start))
     }
-    stop <- start[2];
-    start <- start[1];
+    stop <- start[2]
+    start <- start[1]
   } else if (length(start) != 1) {
-    throw("If argument 'stop' is specified, then argument 'start' must be a single position: ", length(start));
+    throw("If argument 'stop' is specified, then argument 'start' must be a single position: ", length(start))
   }
 
   CopyNumberRegions(chromosome=chromosome,
                     start=xScale*start, stop=xScale*stop,
-                    mean=mean, ...);
+                    mean=mean, ...)
 } # cnr()
 
 
 setMethodS3("getXScale", "CopyNumberRegions", function(this, ...) {
-  scale <- this$.xScale;
+  scale <- this$.xScale
   if (is.null(scale))
-    scale <- 1e-06;
-  scale;
+    scale <- 1e-06
+  scale
 })
 
 setMethodS3("getYScale", "CopyNumberRegions", function(this, ...) {
-  scale <- this$.yScale;
+  scale <- this$.yScale
   if (is.null(scale))
-    scale <- 1;
-  scale;
+    scale <- 1
+  scale
 })
 
 
 
 setMethodS3("plot", "CopyNumberRegions", function(x, joined=TRUE, xlab="Position", ylab="CN", ylim=c(0,5), xScale=getXScale(this), yScale=getYScale(this), ...) {
   # To please R CMD check
-  this <- x;
+  this <- x
 
   # Argument 'joined':
-  joined <- Arguments$getLogical(joined);
+  joined <- Arguments$getLogical(joined)
 
 
   # Create an empty plot
-  x <- xRange(this);
-  y <- c(0,0);
-  plot(xScale*x, yScale*y, type="n", ylim=ylim, xlab=xlab, ylab=ylab, ...);
+  x <- xRange(this)
+  y <- c(0,0)
+  plot(xScale*x, yScale*y, type="n", ylim=ylim, xlab=xlab, ylab=ylab, ...)
 
   # Draw the levels
   if (joined) {
-    lines(this, ...);
+    lines(this, ...)
   } else {
-    drawLevels(this, ...);
+    drawLevels(this, ...)
   }
 
-  invisible(this);
+  invisible(this)
 })
 
 
